@@ -1,6 +1,7 @@
 #!/bin/sh
 
-# This hackish script really needs to go away. It is embarrasing.
+# qole says: This hackish script really needs to go away. 
+#            It is embarrassing.
 
 cp /usr/share/applications/defaults.list /usr/share/applications/defaults.list~
 
@@ -29,4 +30,6 @@ echo "text/dbs-sh=hildon-dbus-switchboard.desktop" >> /usr/share/applications/de
 echo "text/dbs-tgz=hildon-dbus-switchboard.desktop" >> /usr/share/applications/defaults.list
 echo "text/dbs-xls=hildon-dbus-switchboard.desktop" >> /usr/share/applications/defaults.list
 echo "text/dbs-vb=hildon-dbus-switchboard.desktop" >> /usr/share/applications/defaults.list
-echo "application/dbs-jar=hildon-dbus-switchboard.desktop" >> /usr/share/applications/defaults.list
\ No newline at end of file
+echo "application/dbs-jar=hildon-dbus-switchboard.desktop" >> /usr/share/applications/defaults.list
+
+echo "video-quicktime=hildon-mediaplayer.desktop:X-Osso-URI-Action-Open" >> /usr/share/applications/uri-action-defaults.list
\ No newline at end of file
